@@ -147,7 +147,7 @@ fn gen_method(
     gen: &Gen,
 ) -> TokenStream {
     let signature = method.signature(&[]);
-    let constraints = gen_method_constraints(&signature.params);
+    let constraints = gen_method_constraints(&signature.params, gen);
     let vtable_offset = Literal::usize_unsuffixed(vtable_offset + 3);
 
     let name = method.name();
@@ -161,7 +161,7 @@ fn gen_method(
     };
 
     match signature.kind() {
-        SignatureKind::QueryInterface => {
+        SignatureKind::Query => {
             let leading_params = &signature.params[..signature.params.len() - 2];
             let args = leading_params.iter().map(|p| gen_win32_abi_arg(p));
             let params = gen_win32_params(leading_params, gen);
@@ -173,6 +173,17 @@ fn gen_method(
                 }
             }
         }
+        SignatureKind::QueryOptional => {
+            let leading_params = &signature.params[..signature.params.len() - 2];
+            let args = leading_params.iter().map(|p| gen_win32_abi_arg(p));
+            let params = gen_win32_params(leading_params, gen);
+
+            quote! {
+                pub unsafe fn #name<#constraints T: ::windows::Interface>(&self, #params result__: *mut ::std::option::Option<T>) -> ::windows::Result<()> {
+                    (::windows::Interface::vtable(self).#vtable_offset)(::std::mem::transmute_copy(self), #(#args,)* &<T as ::windows::Interface>::IID, result__ as *mut _ as *mut _).ok()
+                }
+            }
+        }
         SignatureKind::ResultValue => {
             let leading_params = &signature.params[..signature.params.len() - 1];
             let args = leading_params.iter().map(|p| gen_win32_abi_arg(p));
