@@ -3,7 +3,7 @@ use super::*;
 pub fn gen_function(def: &MethodDef, gen: &Gen) -> TokenStream {
     let name = to_ident(def.name());
     let signature = def.signature(&[]);
-    let constraints = gen_method_constraints(&signature.params);
+    let constraints = gen_method_constraints(&signature.params, gen);
 
     let abi_params = signature.params.iter().map(|p| {
         let name = gen_param_name(&p.param);
@@ -41,7 +41,7 @@ pub fn gen_function(def: &MethodDef, gen: &Gen) -> TokenStream {
     };
 
     match signature.kind() {
-        SignatureKind::QueryInterface => {
+        SignatureKind::Query => {
             let leading_params = &signature.params[..signature.params.len() - 2];
             let args = leading_params.iter().map(|p| gen_win32_abi_arg(p));
             let params = gen_win32_params(leading_params, gen);
@@ -62,6 +62,26 @@ pub fn gen_function(def: &MethodDef, gen: &Gen) -> TokenStream {
                 }
             }
         }
+        SignatureKind::QueryOptional => {
+            let leading_params = &signature.params[..signature.params.len() - 2];
+            let args = leading_params.iter().map(|p| gen_win32_abi_arg(p));
+            let params = gen_win32_params(leading_params, gen);
+
+            quote! {
+                pub unsafe fn #name<#constraints T: ::windows::Interface>(#params result__: *mut ::std::option::Option<T>) -> ::windows::Result<()> {
+                    #[cfg(windows)]
+                    {
+                        #link_attr
+                        extern "system" {
+                            fn #name(#(#abi_params),*) #abi_return_type;
+                        }
+                        #name(#(#args,)* &<T as ::windows::Interface>::IID, result__ as *mut _ as *mut _).ok()
+                    }
+                    #[cfg(not(windows))]
+                    unimplemented!("Unsupported target OS");
+                }
+            }
+        }
         SignatureKind::ResultValue => {
             let leading_params = &signature.params[..signature.params.len() - 1];
             let args = leading_params.iter().map(|p| gen_win32_abi_arg(p));
